saruman.tasks.misc package
==========================

Submodules
----------

saruman.tasks.misc.hello_world module
-------------------------------------

.. automodule:: saruman.tasks.misc.hello_world
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: saruman.tasks.misc
    :members:
    :undoc-members:
    :show-inheritance:
